require 'pg'

require 'common/davical_plugin'
require 'rm/rm_plugin'

class DavicalRm
  #
  # DAViCal only supports Postgres, so even if we ever are
  # database-agnostic, this plugin can't be.
  #
  include DavicalPlugin
  include RmPlugin


  def delete_domain(domain)
    # DAViCal doesn't have a concept of domains.
  end


  def delete_account(account)
    # Delete the given username. DAViCal uses foreign keys properly
    # and only supports postgres, so we let the ON DELETE CASCADE
    # trigger handle most of the work.
    sql_queries = ['DELETE FROM usr WHERE username = $1']

    begin
      connection = PGconn.connect(@db_host,
                                  @db_port,
                                  @db_opts,
                                  @db_tty,
                                  @db_name,
                                  @db_user,
                                  @db_pass)

      sql_queries.each do |sql_query|
        connection.query(sql_query, [account])
      end

      connection.close()

    rescue PGError => e
      # Pretend like we're database-agnostic in case we ever are.
      raise DatabaseError.new(e)
    end

  end



  def get_domain_usernames(domain)
    usernames = get_davical_usernames();
    matches = usernames.select do |username|
      username =~ /@#{domain}$/
    end

    return matches
  end

end
