require 'pg'

require 'common/roundcube_db_plugin'
require 'rm/rm_plugin'

class RoundcubeDbRm

  include RoundcubeDbPlugin
  include RmPlugin

  def delete_domain(domain)
    # Roundcube doesn't have a concept of domains.
  end

  def delete_account(account)
    # Delete the given username and any records in other tables
    # belonging to it.
    user_id = self.get_user_id(account)

    # The Roundcube developers were nice enough to include
    # DBMS-specific install and upgrade scripts, so Postgres can take
    # advantage of ON DELETE triggers. Here's an example:
    #
    #  ...
    #  user_id integer NOT NULL
    #    REFERENCES users (user_id) ON DELETE CASCADE ON UPDATE CASCADE
    #
    # This query is of course necessary with any DBMS:
    sql_queries = ['DELETE FROM users WHERE user_id = $1::int;']

    begin
      connection = PGconn.connect(@db_host,
                                  @db_port,
                                  @db_opts,
                                  @db_tty,
                                  @db_name,
                                  @db_user,
                                  @db_pass)

      sql_queries.each do |sql_query|
        connection.query(sql_query, [user_id])
      end

      connection.close()

    rescue PGError => e
      # Pretend like we're database-agnostic in case we ever are.
      raise DatabaseError.new(e)
    end

  end



  def get_domain_usernames(domain)
    usernames = get_roundcube_usernames();
    matches = usernames.select do |username|
      username =~ /@#{domain}$/
    end

    return matches
  end

end
